# -*- coding: utf-8 -*-

_char_mapper = {
    b'\xc4\x8d': b'c', # č
    b'\xc4\x87': b'c', # ć
    b'\xc4\x8c': b'C', # Č
    b'\xc4\x86': b'C', # Ć
    b'\xc5\xa1': b's', # š
    b'\xc5\xa0': b'S', # Š
    b'\xc4\x91': b'd', # đ
    b'\xc4\x90': b'D', # Đ
    b'\xc5\xbe': b'z', # ž
    b'\xc5\xbd': b'Z'  # Ž
}


def clean_text(text):
    """
    sources has issues with all characters outside ascii 256 table so
    manually changing all expected croatian special characters and leaving
    others as "fuzzy" encoded as utf-8.
    """
    text = text.encode('utf-8').strip().replace(b'\n', b'').replace(b'\r', b'')
    for special, new in _char_mapper.items():
        text = text.replace(special, new)
    return text



# -*- coding: utf-8 -*-

from __future__ import absolute_import

from six.moves.urllib.request import urlopen
from bs4 import BeautifulSoup
import re

from .utils import clean_text


_scrap_url = 'https://www.index.hr'
_sections = ['vijesti', 'sport', 'magazin']
_html = urlopen(_scrap_url)
_content = _html.read()
_page = BeautifulSoup(_content, 'html.parser')


def _text(elem):
    return clean_text(elem.get_text()) if elem else ''


def _url(elem):
    return '%s%s' % (_scrap_url, elem.get('href')) if elem else None


def _section_right_data(section):
    for parent in _page.findAll('div', {'class': 'right-part'}):
        items = parent.findAll('a', {'class': '%s-text-hover' % section})
        if not items:
            continue
        return [{
            'type': 'article',
            'text': _text(n),
            'url': _url(n)
        } for n in items]


def _header_data(section):
    cubes = _page.findAll('div', {'class': 'cube-big-mainnews-holder'})
    for cube in cubes:
        if not re.search(r"%s-text-hover" % section, str(cube)):
            continue
        url_elem = cube.find('a', {'class': '%s-text-hover' % section})
        text_elem = cube.find('h2', {'class': 'title'})
        return {
            'type': 'article',
            'text': _text(text_elem),
            'url': _url(url_elem)
        }


def scrapped_data():
    data = []
    for s in _sections:
        data.append({
            'type': 'section',
            'text': s,
            'url': ''
        })
        data.append(_header_data(s))
        data.extend(_section_right_data(s))
    return data



from setuptools import setup, find_packages


setup(
    name='indexhr',
    version='0.5',
    description='index.hr basic news content in the terminal',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    keywords='index hr terminal cli news croatia',
    url='https://github.com/marinko-peso/index-hr',
    author='Marinko Peso',
    author_email='marinko.peso@gmail.com',
    license='MIT',
    packages=find_packages(exclude=['tests*']),
    install_requires=[
        'beautifulsoup4',
        'six'
    ],
    zip_safe=False,
    scripts=['bin/index-hr'],
    classifiers=[
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
    ]
)
